Name:           ceph-ansible
Version:        4.0.41
Release:        1%{?dist}
Summary:        Ansible playbooks for Ceph
# Some files have been copied from Ansible (GPLv3+). For example:
#  library/ceph_facts
#  plugins/actions/config_template.py
#  roles/ceph-common/plugins/actions/config_template.py
License:        ASL 2.0 and GPLv3+
URL:            https://github.com/ceph/ceph-ansible
Source0:        https://github.com/ceph/%{name}/archive/v%{version}%{?milestone}/%{name}-%{version}%{?milestone}.tar.gz

Obsoletes:      ceph-iscsi-ansible <= 1.5

BuildArch:      noarch

BuildRequires: ansible >= 2.9
Requires: ansible >= 2.9

%if 0%{?rhel} == 7
BuildRequires: python2-devel
Requires: python2-netaddr
%else
BuildRequires: python3-devel
Requires: python3-netaddr
%endif

%description
Ansible playbooks for Ceph

%prep
%autosetup -p1 -n %{name}-%{version}%{?milestone}

%build

%install
mkdir -p %{buildroot}%{_datarootdir}/ceph-ansible

for f in ansible.cfg *.yml *.sample group_vars roles library plugins infrastructure-playbooks; do
  cp -a $f %{buildroot}%{_datarootdir}/ceph-ansible
done

pushd %{buildroot}%{_datarootdir}/ceph-ansible
  # These untested playbooks are too unstable for users.
  rm -r infrastructure-playbooks/untested-by-ci
  %if ! 0%{?fedora} && ! 0%{?centos}
    # remove ability to install ceph community version
    rm roles/ceph-common/tasks/installs/redhat_{community,dev}_repository.yml
    # Ship only the Red Hat Ceph Storage config (overwrite upstream settings)
    cp group_vars/rhcs.yml.sample group_vars/all.yml.sample
  %endif
popd

%check
# Borrowed from upstream's .travis.yml:
ansible-playbook -i dummy-ansible-hosts test.yml --syntax-check

%files
%doc README.rst
%license LICENSE
%{_datarootdir}/ceph-ansible

%changelog
* Tue Dec 01 2020 Thomas Serlin <tserlin@redhat.com> 4.0.41-1
- Update to 4.0.41 (rhbz#1898486,rhbz#1902149,rhbz#1902281)

* Wed Nov 18 2020 Thomas Serlin <tserlin@redhat.com> 4.0.40-1
- Update to 4.0.40 (rhbz#1898856)

* Tue Nov 17 2020 Thomas Serlin <tserlin@redhat.com> 4.0.39-1
- Update to 4.0.39 (rhbz#1887716)

* Thu Nov 12 2020 Thomas Serlin <tserlin@redhat.com> 4.0.38-1
- Update to 4.0.38 (rhbz#1889426,rhbz#1881288)

* Fri Nov 06 2020 Thomas Serlin <tserlin@redhat.com> 4.0.34.2-1
- Update to 4.0.34.2 (rhbz#1890119,rhbz#1893989)

* Tue Sep 22 2020 Thomas Serlin <tserlin@redhat.com> 4.0.34-1
- Update to 4.0.34 (rhbz#1859872,rhbz#1880252)

* Thu Sep 17 2020 Thomas Serlin <tserlin@redhat.com> 4.0.33-1
- Update to 4.0.33 (rhbz#1879178,rhbz#1873915,rhbz#1861755,rhbz#1876692)
- ceph-ansible.spec: bump to ansible 2.9 (rhbz#1879178)

* Fri Sep 11 2020 Thomas Serlin <tserlin@redhat.com> 4.0.32-1
- Update to 4.0.32 (rhbz#1856981,rhbz#1855439,rhbz#1847166,rhbz#1841436)

* Wed Jul 29 2020 Thomas Serlin <tserlin@redhat.com> 4.0.25.2-1
- Update to 4.0.25.2 (rhbz#1861688)

* Mon Jul 27 2020 Thomas Serlin <tserlin@redhat.com> 4.0.25.1-1
- Update to 4.0.25.1 (rhbz#1859173,rhbz#1858865)

* Tue Jun 23 2020 Thomas Serlin <tserlin@redhat.com> 4.0.25-1
- Update to 4.0.25 (rhbz#1845668,rhbz#1846995,rhbz#1834974,rhbz#1849559)

* Thu Jun 18 2020 Thomas Serlin <tserlin@redhat.com> 4.0.24-1
- Update to 4.0.24 (rhbz#1797774,rhbz#1843569,rhbz#1829389,rhbz#1843500,rhbz#1827607,rhbz#1829985,rhbz#1846995,rhbz#1844496,rhbz#1839228)

* Wed May 06 2020 Thomas Serlin <tserlin@redhat.com> 4.0.23-1
- Update to 4.0.23 (rhbz#1747206,rhbz#1831285,rhbz#1831342)

* Thu Apr 23 2020 Thomas Serlin <tserlin@redhat.com> 4.0.22-1
- Update to 4.0.22 (rhbz#1827299)

* Thu Apr 23 2020 Thomas Serlin <tserlin@redhat.com> 4.0.21-1
- Update to 4.0.21 (rhbz#1826884)

* Mon Apr 20 2020 Thomas Serlin <tserlin@redhat.com> 4.0.20-1
- Update to 4.0.20 (rhbz#1793542,rhbz#1790472)

* Tue Apr 14 2020 Thomas Serlin <tserlin@redhat.com> 4.0.19-1
- Update to 4.0.19 (rhbz#1822328,rhbz#1822599)

* Mon Apr 06 2020 Thomas Serlin <tserlin@redhat.com> 4.0.18-1
- Update to 4.0.18 (rhbz#1816713,rhbz#1814542,rhbz#1819681,rhbz#1817586,rhbz#1816989,rhbz#1820233)

* Fri Mar 20 2020 Thomas Serlin <tserlin@redhat.com> 4.0.17-1
- Update to 4.0.17 (rhbz#1810176,rhbz#1623586,rhbz#1811547,rhbz#1814942)

* Fri Mar 13 2020 Thomas Serlin <tserlin@redhat.com> 4.0.16-1
- Update to 4.0.16 (rhbz#1808495,rhbz#1807085,rhbz#1790479,rhbz#1782253,rhbz#1805643,rhbz#1786684,rhbz#1796453,rhbz#1747206,rhbz#1792230)

* Thu Mar 12 2020 Thomas Serlin <tserlin@redhat.com> 4.0.15-1
- Update to 4.0.15 (rhbz#1792225,rhbz#1801319,rhbz#1731148,rhbz#1794351,rhbz#1795509,rhbz#1798781,rhbz#1784011,rhbz#1783223,rhbz#1790472,rhbz#1793564,rhbz#1796853,rhbz#1785736)

* Thu Mar 12 2020 Thomas Serlin <tserlin@redhat.com> - 4.0.14-2
- spec: allow installation from custom repo

* Wed Jan 29 2020 Thomas Serlin <tserlin@redhat.com> 4.0.14-1
- Update to 4.0.14 (rhbz#1795792)

* Mon Jan 27 2020 Thomas Serlin <tserlin@redhat.com> 4.0.13-1
- Update to 4.0.13 (rhbz#1794900)

* Thu Jan 23 2020 Ken Dreyer <kdreyer@redhat.com> 4.0.12-1
- Update to 4.0.12 (rhbz#1792320 rhbz#1794195)

* Wed Jan 22 2020 Ken Dreyer <kdreyer@redhat.com> 4.0.11-1
- Update to 4.0.11 (rhbz#1792227 rhbz#1793885 rhbz#1791838 rhbz#1729267)

* Wed Jan 15 2020 Thomas Serlin <tserlin@redhat.com> 4.0.10-1
- Update to 4.0.10 (rhbz#1791282,rhbz#1787531)

* Tue Jan 14 2020 Thomas Serlin <tserlin@redhat.com> 4.0.9-1
- Update to 4.0.9 (rhbz#1790508,rhbz#1790303,rhbz#1739365,rhbz#1790212,rhbz#1786682)

* Fri Jan 10 2020 Thomas Serlin <tserlin@redhat.com> 4.0.8-1
- Update to 4.0.8 (rhbz#1786682,rhbz#1786686)

* Thu Jan 09 2020 Thomas Serlin <tserlin@redhat.com> 4.0.7-1
- Update to 4.0.7 (rhbz#1765485,rhbz#1783908,rhbz#1786110,rhbz#1787543,rhbz#1787531,rhbz#1622688,rhbz#1783520,rhbz#1677431,rhbz#1789091,rhbz#1729267)

* Wed Dec 11 2019 Thomas Serlin <tserlin@redhat.com> 4.0.6-1
- Update to 4.0.6 (rhbz#1779092,rhbz#1765485,rhbz#1762168,rhbz#1773489,rhbz#1766064,rhbz#1777829,rhbz#1780122,rhbz#1769710,rhbz#1729267)

* Thu Nov 21 2019 Thomas Serlin <tserlin@redhat.com> 4.0.5-1
- Update to 4.0.5 (rhbz#1767365)

* Fri Oct 25 2019 Thomas Serlin <tserlin@redhat.com> 4.0.4-1
- Update to 4.0.4 (rhbz#1763139)

* Wed Oct 23 2019 Thomas Serlin <tserlin@redhat.com> 4.0.3-1
- Update to 4.0.3 (rhbz#1761612,rhbz#1764173,rhbz#1763139)

* Thu Oct 17 2019 Thomas Serlin <tserlin@redhat.com> - 4.0.2-2
- Sync spec file with upstream

* Wed Oct 16 2019 Thomas Serlin <tserlin@redhat.com> 4.0.2-1
- Update to 4.0.2 (rhbz#1760930,rbhz#1761457)

* Mon Oct 14 2019 Thomas Serlin <tserlin@redhat.com> 4.0.1-1
- Update to 4.0.1 (rhbz#1729267,rhbz#1760897,rhbz#1758099)

* Thu Sep 19 2019 Thomas Serlin <tserlin@redhat.com> 4.0.0-0.1.rc16
- Update to v4.0.0rc16 (rhbz#1748911)

* Thu Sep 05 2019 Thomas Serlin <tserlin@redhat.com> 4.0.0-0.1.rc15
- Update to v4.0.0rc15 (rhbz#1748901)

* Fri Aug 30 2019 Thomas Serlin <tserlin@redhat.com> 4.0.0-0.1.rc14
- Update to v4.0.0rc14 (rhbz#1732157,rhbz#1677431,rhbz#1733251,rhbz#1743242)

* Mon Jul 29 2019 Thomas Serlin <tserlin@redhat.com> 4.0.0-0.1.rc13
- Update to v4.0.0rc13 (rhbz#1726739)

* Tue Jul 23 2019 Thomas Serlin <tserlin@redhat.com> - 4.0.0-0.1.rc12
- Update to v4.0.0rc12 (rhbz#1721536,rhbz#1730541)

* Wed Jul 17 2019 Ken Dreyer <kdreyer@redhat.com> - 4.0.0-0.1.rc11
- Update to v4.0.0rc11 (rhbz#1721531)

* Tue Jul 16 2019 Ken Dreyer <kdreyer@redhat.com> - 4.0.0-0.1.rc10
- Update to 4.0.0rc10

* Thu Jun 13 2019 Thomas Serlin <tserlin@redhat.com> 4.0.0-0.1.rc9
- Update to 4.0.0rc9 (rhbz#1710358,rhbz#1710319,rhbz#1717011,rhbz#1714631,rhbz#1719178)

* Tue Jun 11 2019 Thomas Serlin <tserlin@redhat.com> 4.0.0-0.1.rc8
- Update to 4.0.0rc8 (rhbz#1656591)

* Wed Jun 05 2019 Ken Dreyer <kdreyer@redhat.com> - 4.0.0-0.1.rc7
- Update to 4.0.0rc7

* Thu May 09 2019 Ken Dreyer <kdreyer@redhat.com> - 4.0.0-0.1.rc6
- Update to 4.0.0rc6

* Fri May 03 2019 Ken Dreyer <kdreyer@redhat.com> - 4.0.0-0.1.rc5
- Update to 4.0.0rc5

* Tue Apr 30 2019 Thomas Serlin <tserlin@redhat.com> 4.0.0-0.1.rc4
- Update to 4.0.0rc4 (rhbz#1700548)

* Wed Apr 10 2019 Ken Dreyer <kdreyer@redhat.com> - 4.0.0-0.rc3.10.ga718ddec
- initial package
